pub type InitialRoomJoinRulesEvent = InitialStateEvent<RoomJoinRulesEventContent>;Expand description
An m.room.join_rules event for creating a room.
Aliased Type
pub struct InitialRoomJoinRulesEvent {
pub content: RoomJoinRulesEventContent,
pub state_key: EmptyStateKey,
}Fields
content: RoomJoinRulesEventContentData specific to the event type.
state_key: EmptyStateKeyA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.
Defaults to the empty string.